@@ -1,6 +1,6 @@
 [ ! -f Makefile ] \
     && ./autogen.sh \
-    && ./configure --with-rebar=./rebar3 \
+    && ./configure --with-rebar=rebar3 \
     && make deps
 
 make relive
