@@ -3,11 +3,12 @@ defmodule Ejabberd.Config.Validator.Attrs do
   Validator module used to validate attributes.
   """
 
-  # TODO: Duplicated from validator.ex !!!
-  @type mod_validation :: {[EjabberdModule.t], EjabberdModule.t, map}
-
   import Ejabberd.Config.ValidatorUtility
   alias Ejabberd.Config.Attr
+  alias Ejabberd.Config.EjabberdModule
+
+  # TODO: Duplicated from validator.ex !!!
+  @type mod_validation :: {[EjabberdModule.t], EjabberdModule.t, map}
 
   @doc """
   Given a module (with the form used for validation)
@@ -17,9 +18,9 @@ defmodule Ejabberd.Config.Validator.Attrs do
   @spec validate(mod_validation) :: mod_validation
   def validate({modules, mod, errors}) do
     errors = Enum.reduce mod.attrs, errors, fn(attr, err) ->
-      case Attr.validate(attr) do
-        {:ok, _attr} -> err
-        {:error, attr, cause} -> put_error(err, :attribute, {attr, cause})
+      case Attr.validate([attr]) do
+        [{:ok, _attr}] -> err
+        [{:error, attr, cause}] -> put_error(err, :attribute, {attr, cause})
       end
     end
 
