@@ -1,4 +1,4 @@
-PWD_DIR=`pwd`
+PWD_DIR=$(pwd)
 REL_DIR=$PWD_DIR/_build/relive/
 CON_DIR=$REL_DIR/conf/
 
@@ -15,17 +15,17 @@ cp ejabberd.yml.example $CON_DIR/ejabberd.yml.example
 cp test/ejabberd_SUITE_data/ca.pem $CON_DIR
 cp test/ejabberd_SUITE_data/cert.pem $CON_DIR
 
-cd $CON_DIR_TEMP
+cd $CON_DIR_TEMP || exit
 
 sed -i "s|# certfiles:|certfiles:\n  - $CON_DIR/cert.pem|g" ejabberd.yml.example
 sed -i "s|certfiles:|ca_file: $CON_DIR/ca.pem\ncertfiles:|g" ejabberd.yml.example
 sed -i 's|^acl:$|acl:\n  admin: [user: admin]|g' ejabberd.yml.example
 [ ! -f "$CON_DIR/ejabberd.yml" ] \
-    && echo -n "ejabberd.yml " \
+    && printf "ejabberd.yml " \
     && mv ejabberd.yml.example ejabberd.yml
 
 sed -i "s|#' POLL|EJABBERD_BYPASS_WARNINGS=true\n\n#' POLL|g" ejabberdctl.cfg.example
 [ ! -f "$CON_DIR/ejabberdctl.cfg" ] \
-    && echo -n "ejabberdctl.cfg " \
+    && printf "ejabberdctl.cfg " \
     && mv ejabberdctl.cfg.example ejabberdctl.cfg \
-    || echo -n
+    || printf
