@@ -1,5 +1,5 @@
 --
--- ejabberd, Copyright (C) 2002-2023   ProcessOne
+-- ejabberd, Copyright (C) 2002-2024   ProcessOne
 --
 -- This program is free software; you can redistribute it and/or
 -- modify it under the terms of the GNU General Public License as
@@ -31,6 +31,7 @@ CREATE TABLE [dbo].[archive] (
         [id] [bigint] IDENTITY(1,1) NOT NULL,
         [kind] [varchar] (10) NULL,
         [nick] [varchar] (250) NULL,
+        [origin_id] [varchar] (250) NOT NULL,
         [created_at] [datetime] NOT NULL DEFAULT GETDATE(),
  CONSTRAINT [archive_PK] PRIMARY KEY CLUSTERED
 (
@@ -50,6 +51,9 @@ WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW
 CREATE INDEX [archive_timestamp] ON [archive] (timestamp)
 WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON);
 
+CREATE INDEX [archive_username_origin_id] ON [archive] (username, origin_id)
+WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON);
+
 CREATE TABLE [dbo].[archive_prefs] (
         [username] [varchar] (250) NOT NULL,
         [def] [text] NOT NULL,
