@@ -59,10 +59,14 @@ start(normal, _Args) ->
 			ejabberd_hooks:run(ejabberd_started, []),
 			ejabberd:check_apps(),
 			ejabberd_systemd:ready(),
+			maybe_start_exsync(),
 			{T2, _} = statistics(wall_clock),
 			?INFO_MSG("ejabberd ~ts is started in the node ~p in ~.2fs",
 				  [ejabberd_option:version(),
 				   node(), (T2-T1)/1000]),
+			maybe_print_elixir_version(),
+			?INFO_MSG("~ts",
+				  [erlang:system_info(system_version)]),
 			{ok, SupPid};
 		    Err ->
 			?CRITICAL_MSG("Failed to start ejabberd application: ~p", [Err]),
@@ -175,7 +179,11 @@ file_queue_init() ->
 -ifdef(ELIXIR_ENABLED).
 is_using_elixir_config() ->
     Config = ejabberd_config:path(),
-    'Elixir.Ejabberd.ConfigUtil':is_elixir_config(Config).
+    try 'Elixir.Ejabberd.ConfigUtil':is_elixir_config(Config) of
+        B when is_boolean(B) -> B
+    catch
+        _:_ -> false
+    end.
 
 setup_if_elixir_conf_used() ->
   case is_using_elixir_config() of
@@ -194,8 +202,19 @@ start_elixir_application() ->
 	ok -> ok;
 	{error, _Msg} -> ?ERROR_MSG("Elixir application not started.", [])
     end.
+
+maybe_start_exsync() ->
+    case os:getenv("RELIVE") of
+        "true" -> rpc:call(node(), 'Elixir.ExSync.Application', start, []);
+        _ -> ok
+    end.
+
+maybe_print_elixir_version() ->
+    ?INFO_MSG("Elixir ~ts", [maps:get(build, 'Elixir.System':build_info())]).
 -else.
 setup_if_elixir_conf_used() -> ok.
 register_elixir_config_hooks() -> ok.
 start_elixir_application() -> ok.
+maybe_start_exsync() -> ok.
+maybe_print_elixir_version() -> ok.
 -endif.
