@@ -27,7 +27,7 @@
 -protocol({rfc, 3921}).
 -protocol({rfc, 6120}).
 -protocol({rfc, 6121}).
--protocol({xep, 138, '2.1'}).
+-protocol({xep, 138, '2.1', '1.1.0', "complete", ""}).
 
 %% ejabberd_listener callbacks
 -export([start/3, start_link/3, accept/1, listen_opt_type/1, listen_options/0]).
@@ -45,7 +45,8 @@
 	 handle_unbinded_packet/2, inline_stream_features/1,
 	 handle_sasl2_inline/2, handle_sasl2_inline_post/3,
 	 handle_bind2_inline/2, handle_bind2_inline_post/3, sasl_options/1,
-	 handle_sasl2_task_next/4, handle_sasl2_task_data/3]).
+	 handle_sasl2_task_next/4, handle_sasl2_task_data/3,
+	 get_fast_tokens_fun/2, fast_mechanisms/1]).
 %% Hooks
 -export([handle_unexpected_cast/2, handle_unexpected_call/3,
 	 process_auth_result/3, reject_unauthenticated_packet/2,
@@ -465,6 +466,20 @@ check_password_digest_fun(_Mech, #{lserver := LServer}) ->
 	    ejabberd_auth:check_password_with_authmodule(U, AuthzId, LServer, P, D, DG)
     end.
 
+get_fast_tokens_fun(_Mech, #{lserver := LServer}) ->
+    fun(User, UA) ->
+	case gen_mod:is_loaded(LServer, mod_auth_fast) of
+	    false -> false;
+	    _  -> mod_auth_fast:get_tokens(LServer, User, UA)
+	end
+    end.
+
+fast_mechanisms(#{lserver := LServer}) ->
+    case gen_mod:is_loaded(LServer, mod_auth_fast) of
+	false -> [];
+	_  -> mod_auth_fast:get_mechanisms(LServer)
+    end.
+
 bind(<<"">>, State) ->
     bind(new_uniq_id(), State);
 bind(R, #{user := U, server := S, access := Access, lang := Lang,
