@@ -87,7 +87,7 @@ md_tag(h2, V) ->
 md_tag(strong, V) ->
     [<<"*">>, V, <<"*">>];
 md_tag('div', V) ->
-    [<<"<div class='note-down'>">>, V, <<"</div>">>];
+    [<<"*Note* about this command: ">>, V, <<".">>];
 md_tag(_, V) ->
     V.
 
@@ -237,7 +237,7 @@ json_gen({_Name, {list, ElDesc}}, List, Indent, HTMLOutput) ->
     [?OP_L("["), ?BR, Indent2, list_join_with(Res, [?OP_L(","), ?BR, Indent2]), ?BR, Indent, ?OP_L("]")].
 
 json_call(Name, ArgsDesc, Values, ResultDesc, Result, HTMLOutput) ->
-    {Indent, Preamble} = if HTMLOutput -> {<<"">>, []}; true -> {<<"    ">>, <<"~~~ json\n">>} end,
+    {Indent, Preamble} = if HTMLOutput -> {<<"">>, []}; true -> {<<"">>, <<"~~~ json\n">>} end,
     {Code, ResultStr} = case {ResultDesc, Result} of
                             {{_, rescode}, V} when V == true; V == ok ->
                                 {200, [?STR_L("")]};
@@ -247,13 +247,8 @@ json_call(Name, ArgsDesc, Values, ResultDesc, Result, HTMLOutput) ->
                                 {200, [?STR(Text1)]};
                             {{_, restuple}, {_, Text2}} ->
                                 {500, [?STR(Text2)]};
-                            {{_, {list, _}}, _} ->
-                                {200, json_gen(ResultDesc, Result, Indent, HTMLOutput)};
-                            {{_, {tuple, _}}, _} ->
-                                {200, json_gen(ResultDesc, Result, Indent, HTMLOutput)};
-                            {{Name0, _}, _} ->
-                                {200, [Indent, ?OP_L("{"), ?STR_A(Name0), ?OP_L(": "),
-				       json_gen(ResultDesc, Result, Indent, HTMLOutput), ?OP_L("}")]}
+                            {{_, _}, _} ->
+                                {200, json_gen(ResultDesc, Result, Indent, HTMLOutput)}
                         end,
     CodeStr = case Code of
                   200 -> <<" 200 OK">>;
@@ -369,7 +364,7 @@ make_tags(HTMLOutput) ->
 
 -dialyzer({no_match, gen_tags/2}).
 gen_tags({TagName, Commands}, HTMLOutput) ->
-    [?TAG(h1, TagName) | [?TAG(p, ?RAW("* *`"++C++"`*")) || C <- Commands]].
+    [?TAG(h1, TagName) | [?TAG(p, ?RAW("* _`"++C++"`_")) || C <- Commands]].
 
 gen_doc(#ejabberd_commands{name=Name, tags=Tags, desc=Desc, longdesc=LongDesc,
                            args=Args, args_desc=ArgsDesc, note=Note, definer=Definer,
@@ -400,14 +395,14 @@ gen_doc(#ejabberd_commands{name=Name, tags=Tags, desc=Desc, longdesc=LongDesc,
                                  [?TAG(dl, [gen_param(RName, Type, ResultDesc, HTMLOutput)])]
                            end
                      end,
-        TagsText = ?RAW(string:join(["*`"++atom_to_list(Tag)++"`*" || Tag <- Tags], ", ")),
+        TagsText = ?RAW(string:join(["_`"++atom_to_list(Tag)++"`_" || Tag <- Tags], ", ")),
         IsDefinerMod = case Definer of
                          unknown -> false;
                          _ -> lists:member(gen_mod, proplists:get_value(behaviour, Definer:module_info(attributes)))
                      end,
         ModuleText = case IsDefinerMod of
                        true ->
-                           [?TAG(h2, <<"Module:">>), ?TAG(p, ?RAW("*`"++atom_to_list(Definer)++"`*"))];
+                           [?TAG(h2, <<"Module:">>), ?TAG(p, ?RAW("_`"++atom_to_list(Definer)++"`_"))];
                        false ->
                            []
                    end,
@@ -420,8 +415,8 @@ gen_doc(#ejabberd_commands{name=Name, tags=Tags, desc=Desc, longdesc=LongDesc,
             true -> {NoteEl, []}
         end,
 
-        [NotePre,
-         ?TAG(h1, atom_to_list(Name)),
+        [?TAG(h1, make_command_name(Name, Note)),
+         NotePre,
          ?TAG(p, ?RAW(Desc)),
          case LongDesc of
              "" -> [];
@@ -440,6 +435,19 @@ gen_doc(#ejabberd_commands{name=Name, tags=Tags, desc=Desc, longdesc=LongDesc,
 				     [Name, Ex])))
     end.
 
+get_version_mark("") ->
+    "";
+get_version_mark(Note) ->
+    [XX, YY | _] = string:tokens(binary_to_list(ejabberd_option:version()), "."),
+    XXYY = string:join([XX, YY], "."),
+    case string:find(Note, XXYY) of
+        nomatch -> "";
+        _ -> " 🟤"
+    end.
+
+make_command_name(Name, Note) ->
+    atom_to_list(Name) ++ get_version_mark(Note).
+
 find_commands_definitions() ->
     lists:flatmap(
         fun(Mod) ->
@@ -497,21 +505,22 @@ generate_md_output(File, RegExp, Languages, Cmds) ->
                        end, Cmds2),
     Cmds4 = [maybe_add_policy_arguments(Cmd) || Cmd <- Cmds3],
     Langs = binary:split(Languages, <<",">>, [global]),
-    Header = <<"---\ntitle: Administration API reference\ntoc: true\nmenu: API Reference\norder: 1\n"
-	    "// Autogenerated with 'ejabberdctl gen_markdown_doc_for_commands'\n---\n\n"
-	    "This section describes API of ejabberd.\n">>,
+    Version = binary_to_list(ejabberd_config:version()),
+    Header = ["# API Reference\n\n"
+            "This section describes API commands of ejabberd ", Version, ". "
+            "The commands that changed in this version are marked with 🟤.\n\n"],
     Out = lists:map(fun(C) -> gen_doc(C, false, Langs) end, Cmds4),
-    {ok, Fh} = file:open(File, [write]),
+    {ok, Fh} = file:open(File, [write, {encoding, utf8}]),
     io:format(Fh, "~ts~ts", [Header, Out]),
     file:close(Fh),
     ok.
 
 generate_tags_md(File) ->
-    Header = <<"---\ntitle: API Tags\ntoc: true\nmenu: API Tags\norder: 2\n"
-	    "// Autogenerated with 'ejabberdctl gen_markdown_doc_for_tags'\n---\n\n"
-	    "This section enumerates the tags and their associated API.\n">>,
+    Version = binary_to_list(ejabberd_config:version()),
+    Header = ["# API Tags\n\n"
+            "This section enumerates the API tags of ejabberd ", Version, ". \n\n"],
     Tags = make_tags(false),
-    {ok, Fh} = file:open(File, [write]),
+    {ok, Fh} = file:open(File, [write, {encoding, utf8}]),
     io:format(Fh, "~ts~ts", [Header, Tags]),
     file:close(Fh),
     ok.
