@@ -410,6 +410,5 @@ listen_options() ->
                  " method may be removed in a future ejabberd release. You are "
                  "encouraged to define ejabberd_xmlrpc inside request_handlers "
                  "option of ejabberd_http listen module. See the ejabberd "
-                 "documentation for details: https://docs.ejabberd.im/admin/"
-                 "configuration/listen/#ejabberd-xmlrpc", []),
+                 "documentation for details: _`/admin/configuration/listen/#ejabberd-xmlrpc|ejabberd_xmlrpc listener`_.", []),
     [].
