@@ -43,7 +43,8 @@
 	 % Sessions
 	 num_resources/2, resource_num/3,
 	 kick_session/4, status_num/2, status_num/1,
-	 status_list/2, status_list/1, connected_users_info/0,
+	 status_list/2, status_list_v3/2,
+	 status_list/1, status_list_v3/1, connected_users_info/0,
 	 connected_users_vhost/1, set_presence/7,
 	 get_presence/2, user_sessions_info/2, get_last/2, set_last/4,
 
@@ -274,9 +275,9 @@ get_commands_spec() ->
 			longdesc = "This command kicks the account sessions, "
                         "sets a random password, and stores ban details in the "
                         "account private storage. "
-                        "This command requires mod_private to be enabled. "
+                        "This command requires _`mod_private`_ to be enabled. "
                         "Check also _`get_ban_details`_ API "
-                        "and `_unban_account`_ API.",
+                        "and _`unban_account`_ API.",
 			module = ?MODULE, function = ban_account_v2,
 			version = 2,
 			note = "improved in 24.06",
@@ -380,6 +381,21 @@ get_commands_spec() ->
 								{status, string}
 							       ]}}
 					 }}},
+     #ejabberd_commands{name = status_list_host, tags = [session],
+			desc = "List of users logged in host with their statuses",
+			module = ?MODULE, function = status_list_v3,
+			version = 3,
+			note = "updated in 24.12",
+			args = [{host, binary}, {status, binary}],
+			args_example = [<<"myserver.com">>, <<"dnd">>],
+			args_desc = ["Server name", "Status type to check"],
+			result_example = [{<<"peter@myserver.com/tka">>,6,<<"Busy">>}],
+			result = {users, {list,
+					  {userstatus, {tuple, [{jid, string},
+								{priority, integer},
+								{status, string}
+							       ]}}
+					 }}},
      #ejabberd_commands{name = status_list, tags = [session],
 			desc = "List of logged users with this status",
 			module = ?MODULE, function = status_list,
@@ -396,6 +412,21 @@ get_commands_spec() ->
 								{status, string}
 							       ]}}
 					 }}},
+     #ejabberd_commands{name = status_list, tags = [session],
+			desc = "List of logged users with this status",
+			module = ?MODULE, function = status_list_v3,
+			version = 3,
+			note = "updated in 24.12",
+			args = [{status, binary}],
+			args_example = [<<"dnd">>],
+			args_desc = ["Status type to check"],
+			result_example = [{<<"peter@myserver.com/tka">>,6,<<"Busy">>}],
+			result = {users, {list,
+					  {userstatus, {tuple, [{jid, string},
+								{priority, integer},
+								{status, string}
+							       ]}}
+					 }}},
      #ejabberd_commands{name = connected_users_info,
 			tags = [session],
 			desc = "List all established sessions and their information",
@@ -426,8 +457,9 @@ get_commands_spec() ->
 			module = ?MODULE, function = connected_users_vhost,
 			args_example = [<<"myexample.com">>],
 			args_desc = ["Server name"],
-			result_example = [<<"user1@myserver.com/tka">>, <<"user2@localhost/tka">>],
 			args = [{host, binary}],
+			result_example = [<<"user1@myserver.com/tka">>, <<"user2@localhost/tka">>],
+			result_desc = "List of sessions full JIDs",
 			result = {connected_users_vhost, {list, {sessions, string}}}},
      #ejabberd_commands{name = user_sessions_info,
 			tags = [session],
@@ -683,6 +715,7 @@ get_commands_spec() ->
 			module = ?MODULE, function = get_roster,
 			args = [],
 			args_rename = [{server, host}],
+			result_example = [{<<"user2@localhost">>, <<"User 2">>, <<"none">>, <<"subscribe">>, [<<"Group1">>]}],
 			result = {contacts, {list, {contact, {tuple, [
 								      {jid, string},
 								      {nick, string},
@@ -696,6 +729,7 @@ get_commands_spec() ->
                         policy = user,
 			module = ?MODULE, function = get_roster_count,
 			args = [],
+			args_example = [<<"sun">>, <<"localhost">>],
 			args_rename = [{server, host}],
 			result_example = 5,
 			result_desc = "Number",
@@ -1333,6 +1367,14 @@ status_list(Host, Status) ->
 status_list(Status) ->
     status_list(<<"all">>, Status).
 
+status_list_v3(ArgHost, Status) ->
+    List = status_list(ArgHost, Status),
+    [{jid:encode(jid:make(User, Host, Resource)), Priority, StatusText}
+     || {User, Host, Resource, Priority, StatusText} <- List].
+
+status_list_v3(Status) ->
+    status_list_v3(<<"all">>, Status).
+
 
 get_status_list(Host, Status_required) ->
     %% Get list of all logged users
@@ -2283,7 +2325,9 @@ web_page_node(_, Node, #request{path = [<<"stats">>]} = R) ->
                               ejabberd_web_admin,
                               make_command,
                               [stats, R, [{<<"name">>, <<"uptimeseconds">>}], [{only, value}]]),
-    UpDaysBin = integer_to_binary(binary_to_integer(fxml:get_tag_cdata(UpSecs)) div 24000),
+    UpDaysBin =
+        integer_to_binary(binary_to_integer(fxml:get_tag_cdata(UpSecs))
+                          div 86400), % 24*60*60
     UpDays =
         #xmlel{name = <<"code">>,
                attrs = [],
@@ -2324,22 +2368,22 @@ mod_doc() ->
     #{desc =>
           [?T("This module provides additional administrative commands."), "",
            ?T("Details for some commands:"), "",
-           ?T("- 'ban_account':"),
+           ?T("_`ban_account`_ API:"),
            ?T("This command kicks all the connected sessions of the account "
 	      "from the server. It also changes their password to a randomly "
 	      "generated one, so they can't login anymore unless a server "
 	      "administrator changes their password again. It is possible to "
 	      "define the reason of the ban. The new password also includes "
-	      "the reason and the date and time of the ban. See an example below."),
-           ?T("- 'pushroster': (and 'pushroster-all')"),
+	      "the reason and the date and time of the ban. See an example below."), "",
+           ?T("_`push_roster`_ API (and _`push_roster_all`_ API):"),
            ?T("The roster file must be placed, if using Windows, on the "
 	      "directory where you installed ejabberd: "
 	      "`C:/Program Files/ejabberd` or similar. If you use other "
 	      "Operating System, place the file on the same directory where "
-	      "the .beam files are installed. See below an example roster file."),
-           ?T("- 'srg_create':"),
+	      "the .beam files are installed. See below an example roster file."), "",
+           ?T("_`srg_create`_ API:"),
            ?T("If you want to put a group Name with blank spaces, use the "
-	      "characters \"\' and \'\" to define when the Name starts and "
+	      "characters '\"\'' and '\'\"' to define when the Name starts and "
 	      "ends. See an example below.")],
       example =>
 	  [{?T("With this configuration, vCards can only be modified with "
@@ -2354,14 +2398,14 @@ mod_doc() ->
 	     "  mod_admin_extra: {}",
 	     "  mod_vcard:",
 	     "    access_set: vcard_set"]},
-	   {?T("Content of roster file for 'pushroster' command:"),
+	   {?T("Content of roster file for _`push_roster`_ API:"),
 	    ["[{<<\"bob\">>, <<\"example.org\">>, <<\"workers\">>, <<\"Bob\">>},",
 	     "{<<\"mart\">>, <<\"example.org\">>, <<\"workers\">>, <<\"Mart\">>},",
 	     "{<<\"Rich\">>, <<\"example.org\">>, <<\"bosses\">>, <<\"Rich\">>}]."]},
 	   {?T("With this call, the sessions of the local account which JID is "
-	      "boby@example.org will be kicked, and its password will be set "
+	      "'boby@example.org' will be kicked, and its password will be set "
 	      "to something like "
 	      "'BANNED_ACCOUNT--20080425T21:45:07--2176635--Spammed_rooms'"),
 	    ["ejabberdctl vhost example.org ban_account boby \"Spammed rooms\""]},
-	   {?T("Call to srg_create using double-quotes and single-quotes:"),
+	   {?T("Call to _`srg_create`_ API using double-quotes and single-quotes:"),
 	    ["ejabberdctl srg_create g1 example.org \"\'Group number 1\'\" this_is_g1 g1"]}]}.
