@@ -632,6 +632,6 @@ mod_doc() ->
     #{desc =>
           ?T("This module can be used to update existing SQL database "
              "from the default to the new schema. Check the section "
-             "http://../database/#default-and-new-schemas[Default and New Schemas] for details. "
+             "_`database.md#default-and-new-schemas|Default and New Schemas`_ for details. "
              "Please note that only MS SQL, MySQL, and PostgreSQL are supported. "
              "When the module is loaded use _`update_sql`_ API.")}.
