@@ -96,7 +96,7 @@ mod_options(_) ->
 mod_doc() ->
     #{desc =>
           [?T("This module adds quota support for mod_http_upload."), "",
-           ?T("This module depends on 'mod_http_upload'.")],
+           ?T("This module depends on _`mod_http_upload`_.")],
       opts =>
           [{max_days,
             #{value => ?T("Days"),
@@ -126,10 +126,10 @@ mod_doc() ->
                      "user may upload. When this threshold is exceeded, "
                      "ejabberd deletes the oldest files uploaded by that "
                      "user until their disk usage equals or falls below "
-                     "the specified soft quota (see 'access_soft_quota'). "
+                     "the specified soft quota (see also option 'access_soft_quota'). "
                      "The default value is 'hard_upload_quota'.")}}],
       example =>
-	  [{?T("Please note that it's not necessary to specify the "
+	  [{?T("Notice it's not necessary to specify the "
 	       "'access_hard_quota' and 'access_soft_quota' options in order "
 	       "to use the quota feature. You can stick to the default names "
 	       "and just specify access rules such as those in this example:"),
