@@ -4,7 +4,7 @@
 %%% Created : 15 Apr 2016 by Evgeny Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2023   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2024   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -28,8 +28,10 @@
 
 %% API
 -export([init/2, remove_user/2, remove_room/3, delete_old_messages/3,
-	 extended_fields/0, store/8, write_prefs/4, get_prefs/2, select/6, remove_from_archive/3,
-	 is_empty_for_user/2, is_empty_for_room/3, delete_old_messages_batch/5]).
+	 extended_fields/0, store/10, write_prefs/4, get_prefs/2, select/6,
+         remove_from_archive/3,
+	 is_empty_for_user/2, is_empty_for_room/3, delete_old_messages_batch/5,
+         transform/1]).
 
 -include_lib("stdlib/include/ms_transform.hrl").
 -include_lib("xmpp/include/xmpp.hrl").
@@ -75,14 +77,14 @@ remove_user(LUser, LServer) ->
 remove_room(_LServer, LName, LHost) ->
     remove_user(LName, LHost).
 
-remove_from_archive(LUser, LServer, none) ->
-    US = {LUser, LServer},
+remove_from_archive(LUser, LHost, Key) when is_binary(LUser) ->
+    remove_from_archive({LUser, LHost}, LHost, Key);
+remove_from_archive(US, _LServer, none) ->
     case mnesia:transaction(fun () -> mnesia:delete({archive_msg, US}) end) of
 	{atomic, _} -> ok;
 	{aborted, Reason} -> {error, Reason}
     end;
-remove_from_archive(LUser, LServer, #jid{} = WithJid) ->
-    US = {LUser, LServer},
+remove_from_archive(US, _LServer, #jid{} = WithJid) ->
     Peer = jid:remove_resource(jid:split(WithJid)),
     F = fun () ->
 	    Msgs = mnesia:select(
@@ -97,9 +99,8 @@ remove_from_archive(LUser, LServer, #jid{} = WithJid) ->
 	{atomic, _} -> ok;
 	{aborted, Reason} -> {error, Reason}
     end;
-remove_from_archive(LUser, LServer, StanzaId) ->
+remove_from_archive(US, _LServer, StanzaId) ->
     Timestamp = misc:usec_to_now(StanzaId),
-    US = {LUser, LServer},
     F = fun () ->
 	Msgs = mnesia:select(
 	    archive_msg,
@@ -187,7 +188,28 @@ delete_old_messages_batch(LServer, TimeStamp, Type, Batch, LastUS) ->
 extended_fields() ->
     [].
 
-store(Pkt, _, {LUser, LServer}, Type, Peer, Nick, _Dir, TS) ->
+store(Pkt, _, {LUser, LServer}, Type, Peer, Nick, _Dir, TS,
+      OriginID, Retract) ->
+    case Retract of
+        {true, RID} ->
+            mnesia:transaction(
+              fun () ->
+                      {PUser, PServer, _} = jid:tolower(Peer),
+                      Msgs = mnesia:select(
+                               archive_msg,
+                               ets:fun2ms(
+                                 fun(#archive_msg{
+                                        us = US1,
+                                        bare_peer = Peer1,
+                                        origin_id = OriginID1} = Msg)
+                                       when US1 == {LUser, LServer},
+                                            Peer1 == {PUser, PServer, <<>>},
+                                            OriginID1 == RID -> Msg
+                                 end)),
+                      lists:foreach(fun mnesia:delete_object/1, Msgs)
+              end);
+        false -> ok
+    end,
     case {mnesia:table_info(archive_msg, disc_only_copies),
 	  mnesia:table_info(archive_msg, memory)} of
 	{[_|_], TableSize} when TableSize > ?TABLE_SIZE_LIMIT ->
@@ -205,7 +227,8 @@ store(Pkt, _, {LUser, LServer}, Type, Peer, Nick, _Dir, TS) ->
 				       bare_peer = {PUser, PServer, <<>>},
 				       type = Type,
 				       nick = Nick,
-				       packet = Pkt})
+				       packet = Pkt,
+                                       origin_id = OriginID})
 		end,
 	    case mnesia:transaction(F) of
 		{atomic, ok} ->
@@ -330,3 +353,16 @@ filter_by_max(Msgs, Len) when is_integer(Len), Len >= 0 ->
     {lists:sublist(Msgs, Len), length(Msgs) =< Len};
 filter_by_max(_Msgs, _Junk) ->
     {[], true}.
+
+transform({archive_msg, US, ID, Timestamp, Peer, BarePeer,
+           Packet, Nick, Type}) ->
+    #archive_msg{
+       us = US,
+       id = ID,
+       timestamp = Timestamp,
+       peer = Peer,
+       bare_peer = BarePeer,
+       packet = Packet,
+       nick = Nick,
+       type = Type,
+       origin_id = <<"">>}.
