@@ -4,7 +4,7 @@
 %%% Created : 15 Apr 2016 by Evgeny Khramtsov <ekhramtsov@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2023   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2024   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -29,9 +29,10 @@
 
 %% API
 -export([init/2, remove_user/2, remove_room/3, delete_old_messages/3,
-	 extended_fields/0, store/8, write_prefs/4, get_prefs/2, select/7, export/1, remove_from_archive/3,
+	 extended_fields/0, store/10, write_prefs/4, get_prefs/2, select/7, export/1, remove_from_archive/3,
 	 is_empty_for_user/2, is_empty_for_room/3, select_with_mucsub/6,
 	 delete_old_messages_batch/4, count_messages_to_delete/3]).
+-export([sql_schemas/0]).
 
 -include_lib("stdlib/include/ms_transform.hrl").
 -include_lib("xmpp/include/xmpp.hrl").
@@ -44,11 +45,65 @@
 %%% API
 %%%===================================================================
 init(Host, _Opts) ->
-    ejabberd_sql_schema:update_schema(Host, ?MODULE, schemas()),
+    ejabberd_sql_schema:update_schema(Host, ?MODULE, sql_schemas()),
     ok.
 
-schemas() ->
+sql_schemas() ->
     [#sql_schema{
+        version = 2,
+        tables =
+            [#sql_table{
+                name = <<"archive">>,
+                columns =
+                    [#sql_column{name = <<"username">>, type = text},
+                     #sql_column{name = <<"server_host">>, type = text},
+                     #sql_column{name = <<"timestamp">>, type = bigint},
+                     #sql_column{name = <<"peer">>, type = text},
+                     #sql_column{name = <<"bare_peer">>, type = text},
+                     #sql_column{name = <<"xml">>, type = {text, big}},
+                     #sql_column{name = <<"txt">>, type = {text, big}},
+                     #sql_column{name = <<"id">>, type = bigserial},
+                     #sql_column{name = <<"kind">>, type = {text, 10}},
+                     #sql_column{name = <<"nick">>, type = text},
+                     #sql_column{name = <<"origin_id">>, type = text},
+                     #sql_column{name = <<"created_at">>, type = timestamp,
+                                 default = true}],
+                indices = [#sql_index{
+                              columns = [<<"server_host">>, <<"username">>, <<"timestamp">>]},
+                           #sql_index{
+                              columns = [<<"server_host">>, <<"username">>, <<"peer">>]},
+                           #sql_index{
+                              columns = [<<"server_host">>, <<"username">>, <<"bare_peer">>]},
+                           #sql_index{
+                              columns = [<<"server_host">>, <<"timestamp">>]},
+                           #sql_index{
+                              columns = [<<"server_host">>, <<"username">>, <<"origin_id">>]}
+                          ],
+                post_create =
+                    fun(#sql_schema_info{db_type = mysql}) ->
+                            [<<"CREATE FULLTEXT INDEX i_archive_txt ON archive(txt);">>];
+                       (_) ->
+                            []
+                    end},
+             #sql_table{
+                name = <<"archive_prefs">>,
+                columns =
+                    [#sql_column{name = <<"username">>, type = text},
+                     #sql_column{name = <<"server_host">>, type = text},
+                     #sql_column{name = <<"def">>, type = text},
+                     #sql_column{name = <<"always">>, type = text},
+                     #sql_column{name = <<"never">>, type = text},
+                     #sql_column{name = <<"created_at">>, type = timestamp,
+                                 default = true}],
+                indices = [#sql_index{
+                              columns = [<<"server_host">>, <<"username">>],
+                              unique = true}]}],
+        update =
+            [{add_column, <<"archive">>, <<"origin_id">>},
+             {create_index, <<"archive">>,
+              [<<"server_host">>, <<"username">>, <<"origin_id">>]}
+            ]},
+     #sql_schema{
         version = 1,
         tables =
             [#sql_table{
@@ -76,10 +131,10 @@ schemas() ->
                               columns = [<<"server_host">>, <<"timestamp">>]}
                           ],
                 post_create =
-                    fun(mysql, _) ->
+                    fun(#sql_schema_info{db_type = mysql}) ->
                             ejabberd_sql:sql_query_t(
                               <<"CREATE FULLTEXT INDEX i_archive_txt ON archive(txt);">>);
-                       (_, _) ->
+                       (_) ->
                             ok
                     end},
              #sql_table{
@@ -108,6 +163,8 @@ remove_room(LServer, LName, LHost) ->
     LUser = jid:encode({LName, LHost, <<>>}),
     remove_user(LUser, LServer).
 
+remove_from_archive({LUser, LHost}, LServer, Key) ->
+    remove_from_archive(jid:encode({LUser, LHost, <<>>}), LServer, Key);
 remove_from_archive(LUser, LServer, none) ->
     case ejabberd_sql:sql_query(LServer,
 				?SQL("delete from archive where username=%(LUser)s and %(LServer)H")) of
@@ -200,7 +257,8 @@ delete_old_messages(ServerHost, TimeStamp, Type) ->
 extended_fields() ->
     [{withtext, <<"">>}].
 
-store(Pkt, LServer, {LUser, LHost}, Type, Peer, Nick, _Dir, TS) ->
+store(Pkt, LServer, {LUser, LHost}, Type, Peer, Nick, _Dir, TS,
+      OriginID, Retract) ->
     SUser = case Type of
 		chat -> LUser;
 		groupchat -> jid:encode({LUser, LHost, <<>>})
@@ -223,8 +281,19 @@ store(Pkt, LServer, {LUser, LHost}, Type, Peer, Nick, _Dir, TS) ->
 	      _ ->
 		  fxml:element_to_binary(Pkt)
 	  end,
-	case SqlType of
-	  mssql -> case ejabberd_sql:sql_query(
+    case Retract of
+        {true, RID} ->
+            ejabberd_sql:sql_query(
+              LServer,
+              ?SQL("delete from archive"
+                   " where username=%(SUser)s"
+                   " and %(LServer)H"
+                   " and bare_peer=%(BarePeer)s"
+                   " and origin_id=%(RID)s"));
+        false -> ok
+    end,
+    case SqlType of
+        mssql -> case ejabberd_sql:sql_query(
 	           LServer,
 	           ?SQL_INSERT(
 	              "archive",
@@ -236,13 +305,14 @@ store(Pkt, LServer, {LUser, LHost}, Type, Peer, Nick, _Dir, TS) ->
 	               "xml=N%(XML)s",
 	               "txt=N%(Body)s",
 	               "kind=%(SType)s",
-	               "nick=%(Nick)s"])) of
+	               "nick=%(Nick)s",
+	               "origin_id=%(OriginID)s"])) of
 		{updated, _} ->
 		    ok;
 		Err ->
 		    Err
 	    end;
-	    _ -> case ejabberd_sql:sql_query(
+        _ -> case ejabberd_sql:sql_query(
 	           LServer,
 	           ?SQL_INSERT(
 	              "archive",
@@ -254,13 +324,14 @@ store(Pkt, LServer, {LUser, LHost}, Type, Peer, Nick, _Dir, TS) ->
 	               "xml=%(XML)s",
 	               "txt=%(Body)s",
 	               "kind=%(SType)s",
-	               "nick=%(Nick)s"])) of
+	               "nick=%(Nick)s",
+	               "origin_id=%(OriginID)s"])) of
 		{updated, _} ->
 		    ok;
 		Err ->
 		    Err
 	    end
-	end.
+    end.
 
 write_prefs(LUser, _LServer, #archive_prefs{default = Default,
 					   never = Never,
@@ -420,7 +491,7 @@ export(_Server) ->
      {archive_msg,
       fun([Host | HostTail], #archive_msg{us ={LUser, LServer},
                 id = _ID, timestamp = TS, peer = Peer,
-                type = Type, nick = Nick, packet = Pkt})
+                type = Type, nick = Nick, packet = Pkt, origin_id = OriginID})
           when (LServer == Host) or ([LServer] == HostTail)  ->
                 TStmp = misc:now_to_usec(TS),
                 SUser = case Type of
@@ -444,7 +515,8 @@ export(_Server) ->
 	                     "xml=N%(XML)s",
 	                     "txt=N%(Body)s",
 	                     "kind=%(SType)s",
-	                     "nick=%(Nick)s"])];
+	                     "nick=%(Nick)s",
+                             "origin_id=%(OriginID)s"])];
 	                _ -> [?SQL_INSERT(
 	                    "archive",
 	                    ["username=%(SUser)s",
@@ -455,7 +527,8 @@ export(_Server) ->
 	                     "xml=%(XML)s",
 	                     "txt=%(Body)s",
 	                     "kind=%(SType)s",
-	                     "nick=%(Nick)s"])]
+	                     "nick=%(Nick)s",
+                             "origin_id=%(OriginID)s"])]
 		            end;
          (_Host, _R) ->
               []
