@@ -24,7 +24,7 @@
 -module(mod_mix).
 -behaviour(gen_mod).
 -behaviour(gen_server).
--protocol({xep, 369, '0.14.1', '16.03', "", ""}).
+-protocol({xep, 369, '0.14.1', '16.03', "complete", ""}).
 
 %% API
 -export([route/1]).
@@ -122,7 +122,7 @@ mod_doc() ->
               desc =>
                   ?T("This option defines the Jabber IDs of the service. "
                      "If the 'hosts' option is not specified, the only Jabber ID will "
-                     "be the hostname of the virtual host with the prefix \"mix.\". "
+                     "be the hostname of the virtual host with the prefix '\"mix.\"'. "
                      "The keyword '@HOST@' is replaced with the real virtual host name.")}},
            {name,
             #{value => ?T("Name"),
