@@ -22,7 +22,7 @@
 %%%----------------------------------------------------------------------
 -module(mod_mix_pam).
 -behaviour(gen_mod).
--protocol({xep, 405, '0.3.0'}).
+-protocol({xep, 405, '0.3.0', '19.02', "complete", ""}).
 
 %% gen_mod callbacks
 -export([start/2, stop/1, reload/3, depends/2, mod_opt_type/1, mod_options/1]).
@@ -128,7 +128,7 @@ mod_doc() ->
               "The module is needed if MIX compatible clients "
               "on your server are going to join MIX channels "
               "(either on your server or on any remote servers)."), "",
-           ?T("NOTE: 'mod_mix' is not required for this module "
+           ?T("NOTE: _`mod_mix`_ is not required for this module "
               "to work, however, without 'mod_mix_pam' the MIX "
               "functionality of your local XMPP clients will be impaired.")],
       opts =>
