@@ -24,8 +24,7 @@
 %%%----------------------------------------------------------------------
 -module(mod_muc).
 -author('alexey@process-one.net').
--protocol({xep, 45, '1.25'}).
--protocol({xep, 249, '1.2'}).
+-protocol({xep, 45, '1.25', '0.5.0', "complete", ""}).
 -ifndef(GEN_SERVER).
 -define(GEN_SERVER, gen_server).
 -endif.
@@ -995,15 +994,38 @@ iq_disco_items(ServerHost, Host, From, Lang, MaxRoomsDiscoItems, Node, RSM)
 		   #rsm_set{max = Max} ->
 		       Max
 	       end,
-    {Items, HitMax} = lists:foldr(
-	fun(_, {Acc, _}) when length(Acc) >= MaxItems ->
-	    {Acc, true};
-	   (R, {Acc, _}) ->
-	    case get_room_disco_item(R, Query) of
-		{ok, Item} -> {[Item | Acc], false};
-		{error, _} -> {Acc, false}
+    RMod = gen_mod:ram_db_mod(ServerHost, ?MODULE),
+    RsmSupported = RMod:rsm_supported(),
+    GetRooms =
+	fun GetRooms(AccInit, Rooms) ->
+	    {Items, HitMax, DidSkip, Last, First} = lists:foldr(
+		fun(_, {Acc, _, Skip, F, L}) when length(Acc) >= MaxItems ->
+		    {Acc, true, Skip, F, L};
+		   ({RN, _, _} = R, {Acc, _, Skip, F, _}) ->
+		       F2 = if F == undefined -> RN; true -> F end,
+		       case get_room_disco_item(R, Query) of
+			   {ok, Item} -> {[Item | Acc], false, Skip, F2, RN};
+			   {error, _} -> {Acc, false, true, F2, RN}
+		       end
+		end, AccInit, Rooms),
+	    if RsmSupported andalso not HitMax andalso DidSkip ->
+		RSM2 = case RSM of
+			   #rsm_set{'after' = undefined, before = undefined} ->
+			       #rsm_set{max = MaxItems - length(Items), 'after' = Last};
+			   #rsm_set{'after' = undefined} ->
+			       #rsm_set{max = MaxItems - length(Items), 'before' = First};
+			   _ ->
+			       #rsm_set{max = MaxItems - length(Items), 'after' = Last}
+		       end,
+		GetRooms({Items, false, false, undefined, undefined},
+			 get_online_rooms(ServerHost, Host, RSM2));
+		true -> {Items, HitMax}
 	    end
-	end, {[], false}, get_online_rooms(ServerHost, Host, RSM)),
+	end,
+
+    {Items, HitMax} =
+	GetRooms({[], false, false, undefined, undefined},
+		 get_online_rooms(ServerHost, Host, RSM)),
     ResRSM = case Items of
 		 [_|_] when RSM /= undefined; HitMax ->
 		     #disco_item{jid = #jid{luser = First}} = hd(Items),
@@ -1498,12 +1520,12 @@ mod_doc() ->
                   ?T("A small history of the current discussion is sent to users "
                      "when they enter the room. With this option you can define the "
                      "number of history messages to keep and send to users joining the room. "
-                     "The value is a non-negative integer. Setting the value to 0 disables "
+                     "The value is a non-negative integer. Setting the value to '0' disables "
                      "the history feature and, as a result, nothing is kept in memory. "
-                     "The default value is 20. This value affects all rooms on the service. "
+                     "The default value is '20'. This value affects all rooms on the service. "
                      "NOTE: modern XMPP clients rely on Message Archives (XEP-0313), so feel "
                      "free to disable the history feature if you're only using modern clients "
-                     "and have 'mod_mam' module loaded.")}},
+                     "and have _`mod_mam`_ module loaded.")}},
            {host, #{desc => ?T("Deprecated. Use 'hosts' instead.")}},
            {hosts,
             #{value => ?T("[Host, ...]"),
@@ -1594,7 +1616,7 @@ mod_doc() ->
                      "When this option is not defined, message rate is not limited. "
                      "This feature can be used to protect a MUC service from occupant "
                      "abuses and limit number of messages that will be broadcasted by "
-                     "the service. A good value for this minimum message interval is 0.4 second. "
+                     "the service. A good value for this minimum message interval is '0.4' second. "
                      "If an occupant tries to send messages faster, an error is send back "
                      "explaining that the message has been discarded and describing the "
                      "reason why the message is not acceptable.")}},
@@ -1611,7 +1633,7 @@ mod_doc() ->
                      "the presence is cached by ejabberd and only the last presence "
                      "is broadcasted to all occupants in the room after expiration "
                      "of the interval delay. Intermediate presence packets are "
-                     "silently discarded. A good value for this option is 4 seconds.")}},
+                     "silently discarded. A good value for this option is '4' seconds.")}},
            {queue_type,
             #{value => "ram | file",
               desc =>
@@ -1844,7 +1866,7 @@ mod_doc() ->
                     ?T("Maximum number of occupants in the room. "
                        "The default value is '200'.")}},
              {presence_broadcast,
-              #{value => "[moderator | participant | visitor, ...]",
+              #{value => "[Role]",
                 desc =>
                     ?T("List of roles for which presence is broadcasted. "
                        "The list can contain one or several of: 'moderator', "
