@@ -30,7 +30,8 @@
 
 -export([start/2, stop/1, reload/3, depends/2, mod_doc/0,
 	 muc_online_rooms/1, muc_online_rooms_by_regex/2,
-	 muc_register_nick/3, muc_unregister_nick/2,
+	 muc_register_nick/3, muc_register_nick/4,
+	 muc_unregister_nick/2, muc_unregister_nick/3,
 	 create_room_with_opts/4, create_room/3, destroy_room/2,
 	 create_rooms_file/1, destroy_rooms_file/1,
 	 rooms_unused_list/2, rooms_unused_destroy/2,
@@ -38,9 +39,11 @@
 	 get_user_rooms/2, get_user_subscriptions/2, get_room_occupants/2,
 	 get_room_occupants_number/2, send_direct_invitation/5,
 	 change_room_option/4, get_room_options/2,
-	 set_room_affiliation/4, get_room_affiliations/2, get_room_affiliation/3,
-	 subscribe_room/4, subscribe_room_many/3,
-	 unsubscribe_room/2, get_subscribers/2,
+	 set_room_affiliation/4, set_room_affiliation/5, get_room_affiliations/2,
+	 get_room_affiliations_v3/2, get_room_affiliation/3,
+	 subscribe_room/4, subscribe_room/6,
+	 subscribe_room_many/3, subscribe_room_many_v3/4,
+	 unsubscribe_room/2, unsubscribe_room/4, get_subscribers/2,
 	 get_room_serverhost/1,
 	 web_menu_main/2, web_page_main/2,
          web_menu_host/3, web_page_host/3,
@@ -102,7 +105,7 @@ get_commands_spec() ->
 		       module = ?MODULE, function = muc_online_rooms,
 		       args_desc = ["MUC service, or `global` for all"],
 		       args_example = ["conference.example.com"],
-		       result_desc = "List of rooms",
+		       result_desc = "List of rooms JIDs",
 		       result_example = ["room1@conference.example.com", "room2@conference.example.com"],
 		       args = [{service, binary}],
 		       args_rename = [{host, service}],
@@ -133,6 +136,16 @@ get_commands_spec() ->
 		       args = [{nick, binary}, {jid, binary}, {service, binary}],
 		       args_rename = [{host, service}],
 		       result = {res, rescode}},
+     #ejabberd_commands{name = muc_register_nick, tags = [muc],
+		       desc = "Register a nick to a User JID in a MUC service",
+		       module = ?MODULE, function = muc_register_nick,
+		       version = 3,
+		       note = "updated in 24.12",
+		       args_desc = ["nick", "user name", "user host", "MUC service"],
+		       args_example = [<<"Tim">>, <<"tim">>, <<"example.org">>, <<"conference.example.org">>],
+		       args = [{nick, binary}, {user, binary}, {host, binary}, {service, binary}],
+		       args_rename = [{host, service}],
+		       result = {res, rescode}},
      #ejabberd_commands{name = muc_unregister_nick, tags = [muc],
 		       desc = "Unregister the nick registered by that account in the MUC service",
 		       module = ?MODULE, function = muc_unregister_nick,
@@ -141,25 +154,38 @@ get_commands_spec() ->
 		       args = [{jid, binary}, {service, binary}],
 		       args_rename = [{host, service}],
 		       result = {res, rescode}},
+     #ejabberd_commands{name = muc_unregister_nick, tags = [muc],
+		       desc = "Unregister the nick registered by that account in the MUC service",
+		       module = ?MODULE, function = muc_unregister_nick,
+		       version = 3,
+		       note = "updated in 24.12",
+		       args_desc = ["user name", "user host", "MUC service"],
+		       args_example = [<<"tim">>, <<"example.org">>, <<"conference.example.org">>],
+		       args = [{user, binary}, {host, binary}, {service, binary}],
+		       args_rename = [{host, service}],
+		       result = {res, rescode}},
 
      #ejabberd_commands{name = create_room, tags = [muc_room],
 		       desc = "Create a MUC room name@service in host",
 		       module = ?MODULE, function = create_room,
 		       args_desc = ["Room name", "MUC service", "Server host"],
 		       args_example = ["room1", "conference.example.com", "example.com"],
-		       args = [{name, binary}, {service, binary},
+		       args = [{room, binary}, {service, binary},
 			       {host, binary}],
+		       args_rename = [{name, room}],
 		       result = {res, rescode}},
      #ejabberd_commands{name = destroy_room, tags = [muc_room],
 		       desc = "Destroy a MUC room",
 		       module = ?MODULE, function = destroy_room,
 		       args_desc = ["Room name", "MUC service"],
 		       args_example = ["room1", "conference.example.com"],
-		       args = [{name, binary}, {service, binary}],
+		       args = [{room, binary}, {service, binary}],
+		       args_rename = [{name, room}],
 		       result = {res, rescode}},
      #ejabberd_commands{name = create_rooms_file, tags = [muc],
 		       desc = "Create the rooms indicated in file",
 		       longdesc = "Provide one room JID per line. Rooms will be created after restart.",
+                       note = "improved in 24.12",
 		       module = ?MODULE, function = create_rooms_file,
 		       args_desc = ["Path to the text file with one room JID per line"],
 		       args_example = ["/home/ejabberd/rooms.txt"],
@@ -176,7 +202,7 @@ get_commands_spec() ->
 				       [{"members_only","true"},
                                         {"affiliations", "owner:bob@example.com,member:peter@example.com"},
                                         {"subscribers", "bob@example.com:Bob:messages:subject,anne@example.com:Anne:messages"}]],
-		       args = [{name, binary}, {service, binary},
+		       args = [{room, binary}, {service, binary},
 			       {host, binary},
 			       {options, {list,
 					  {option, {tuple,
@@ -184,6 +210,7 @@ get_commands_spec() ->
 						     {value, binary}
 						    ]}}
 					 }}],
+		       args_rename = [{name, room}],
 		       result = {res, rescode}},
      #ejabberd_commands{name = destroy_rooms_file, tags = [muc],
 		       desc = "Destroy the rooms indicated in file",
@@ -289,7 +316,8 @@ get_commands_spec() ->
 		        args_example = ["room1", "conference.example.com"],
 		        result_desc = "The list of occupants with JID, nick and affiliation",
 		        result_example = [{"user1@example.com/psi", "User 1", "owner"}],
-			args = [{name, binary}, {service, binary}],
+			args = [{room, binary}, {service, binary}],
+		        args_rename = [{name, room}],
 			result = {occupants, {list,
 					      {occupant, {tuple,
 							  [{jid, string},
@@ -305,7 +333,8 @@ get_commands_spec() ->
 		        args_example = ["room1", "conference.example.com"],
 		        result_desc = "Number of room occupants",
 		        result_example = 7,
-			args = [{name, binary}, {service, binary}],
+			args = [{room, binary}, {service, binary}],
+		        args_rename = [{name, room}],
 			result = {occupants, integer}},
 
      #ejabberd_commands{name = send_direct_invitation, tags = [muc_room],
@@ -321,8 +350,9 @@ get_commands_spec() ->
 			args_example = [<<"room1">>, <<"conference.example.com">>,
 					<<>>, <<"Check this out!">>,
 					"user2@localhost:user3@example.com"],
-			args = [{name, binary}, {service, binary}, {password, binary},
+			args = [{room, binary}, {service, binary}, {password, binary},
 				{reason, binary}, {users, binary}],
+		        args_rename = [{name, room}],
 		        result = {res, rescode}},
      #ejabberd_commands{name = send_direct_invitation, tags = [muc_room],
 			desc = "Send a direct invitation to several destinations",
@@ -338,8 +368,9 @@ get_commands_spec() ->
 			args_example = [<<"room1">>, <<"conference.example.com">>,
 					<<>>, <<"Check this out!">>,
 					["user2@localhost", "user3@example.com"]],
-			args = [{name, binary}, {service, binary}, {password, binary},
+			args = [{room, binary}, {service, binary}, {password, binary},
 				{reason, binary}, {users, {list, {jid, binary}}}],
+		        args_rename = [{name, room}],
 		        result = {res, rescode}},
 
      #ejabberd_commands{name = change_room_option, tags = [muc_room],
@@ -347,8 +378,9 @@ get_commands_spec() ->
 		       module = ?MODULE, function = change_room_option,
 		       args_desc = ["Room name", "MUC service", "Option name", "Value to assign"],
 		       args_example = ["room1", "conference.example.com", "members_only", "true"],
-		       args = [{name, binary}, {service, binary},
+		       args = [{room, binary}, {service, binary},
 			       {option, binary}, {value, binary}],
+		       args_rename = [{name, room}],
 		       result = {res, rescode}},
      #ejabberd_commands{name = get_room_options, tags = [muc_room],
 		        desc = "Get options from a MUC room",
@@ -357,7 +389,8 @@ get_commands_spec() ->
 		        args_example = ["room1", "conference.example.com"],
 		        result_desc = "List of room options tuples with name and value",
 		        result_example = [{"members_only", "true"}],
-		        args = [{name, binary}, {service, binary}],
+		        args = [{room, binary}, {service, binary}],
+		        args_rename = [{name, room}],
 			result = {options, {list,
 						 {option, {tuple,
 								[{name, string},
@@ -392,6 +425,21 @@ get_commands_spec() ->
 			args = [{user, binary}, {nick, binary}, {room, binary},
 				{nodes, {list, {node, binary}}}],
 			result = {nodes, {list, {node, string}}}},
+     #ejabberd_commands{name = subscribe_room, tags = [muc_room, muc_sub],
+			desc = "Subscribe to a MUC conference",
+			module = ?MODULE, function = subscribe_room,
+			version = 3,
+			note = "updated in 24.12",
+			args_desc = ["user name", "user host", "user nick",
+			    "room name", "MUC service", "list of nodes"],
+			args_example = ["tom", "localhost", "Tom", "room1", "conference.localhost",
+			    ["urn:xmpp:mucsub:nodes:messages", "urn:xmpp:mucsub:nodes:affiliations"]],
+			result_desc = "The list of nodes that has subscribed",
+			result_example = ["urn:xmpp:mucsub:nodes:messages",
+			    "urn:xmpp:mucsub:nodes:affiliations"],
+			args = [{user, binary}, {host, binary}, {nick, binary}, {room, binary},
+                                {service, binary}, {nodes, {list, {node, binary}}}],
+			result = {nodes, {list, {node, string}}}},
      #ejabberd_commands{name = subscribe_room_many, tags = [muc_room, muc_sub],
 			desc = "Subscribe several users to a MUC conference",
 			note = "added in 22.05",
@@ -439,6 +487,32 @@ get_commands_spec() ->
                                 {room, binary},
 				{nodes, {list, {node, binary}}}],
 			result = {res, rescode}},
+     #ejabberd_commands{name = subscribe_room_many, tags = [muc_room, muc_sub],
+			desc = "Subscribe several users to a MUC conference",
+			longdesc = "This command accepts up to 50 users at once "
+                            "(this is configurable with the _`mod_muc_admin`_ option "
+                            "`subscribe_room_many_max_users`)",
+			module = ?MODULE, function = subscribe_room_many_v3,
+			version = 3,
+			note = "updated in 24.12",
+			args_desc = ["List of tuples with users name, host and nick",
+                                     "room name",
+                                     "MUC service",
+                                     "nodes separated by commas: `,`"],
+			args_example = [[{"tom", "localhost", "Tom"},
+                                         {"jerry", "localhost", "Jerry"}],
+                                        "room1", "conference.localhost",
+                                        ["urn:xmpp:mucsub:nodes:messages", "urn:xmpp:mucsub:nodes:affiliations"]],
+			args = [{users, {list,
+                                         {user, {tuple,
+                                                 [{user, binary},
+                                                  {host, binary},
+                                                  {nick, binary}
+                                                 ]}}
+                                        }},
+                                {room, binary}, {service, binary},
+				{nodes, {list, {node, binary}}}],
+			result = {res, rescode}},
      #ejabberd_commands{name = unsubscribe_room, tags = [muc_room, muc_sub],
 			desc = "Unsubscribe from a MUC conference",
 			module = ?MODULE, function = unsubscribe_room,
@@ -446,6 +520,15 @@ get_commands_spec() ->
 			args_example = ["tom@localhost", "room1@conference.localhost"],
 			args = [{user, binary}, {room, binary}],
 			result = {res, rescode}},
+     #ejabberd_commands{name = unsubscribe_room, tags = [muc_room, muc_sub],
+			desc = "Unsubscribe from a MUC conference",
+			module = ?MODULE, function = unsubscribe_room,
+			version = 3,
+			note = "updated in 24.12",
+			args_desc = ["user name", "user host", "room name", "MUC service"],
+			args_example = ["tom", "localhost", "room1", "conference.localhost"],
+			args = [{user, binary}, {host, binary}, {room, binary}, {service, binary}],
+			result = {res, rescode}},
      #ejabberd_commands{name = get_subscribers, tags = [muc_room, muc_sub],
 			desc = "List subscribers of a MUC conference",
 			module = ?MODULE, function = get_subscribers,
@@ -453,7 +536,8 @@ get_commands_spec() ->
 		        args_example = ["room1", "conference.example.com"],
 		        result_desc = "The list of users that are subscribed to that room",
 		        result_example = ["user2@example.com", "user3@example.com"],
-			args = [{name, binary}, {service, binary}],
+			args = [{room, binary}, {service, binary}],
+		        args_rename = [{name, room}],
 			result = {subscribers, {list, {jid, string}}}},
      #ejabberd_commands{name = set_room_affiliation, tags = [muc_room],
 		       desc = "Change an affiliation in a MUC room",
@@ -463,6 +547,19 @@ get_commands_spec() ->
 		       args = [{name, binary}, {service, binary},
 			       {jid, binary}, {affiliation, binary}],
 		       result = {res, rescode}},
+     #ejabberd_commands{name = set_room_affiliation, tags = [muc_room],
+		       desc = "Change an affiliation in a MUC room",
+		       longdesc = "If affiliation is `none`, then the affiliation is removed.",
+		       module = ?MODULE, function = set_room_affiliation,
+		       version = 3,
+		       note = "updated in 24.12",
+		       args_desc = ["room name", "MUC service", "user name", "user host", "affiliation to set"],
+		       args_example = ["room1", "conference.example.com", "sun", "localhost", "member"],
+		       args = [{room, binary}, {service, binary},
+			       {user, binary}, {host, binary}, {affiliation, binary}],
+		       result = {res, rescode}},
+
+
      #ejabberd_commands{name = get_room_affiliations, tags = [muc_room],
 			desc = "Get the list of affiliations of a MUC room",
 			module = ?MODULE, function = get_room_affiliations,
@@ -479,6 +576,25 @@ get_commands_spec() ->
 								 {reason, string}
 								]}}
 						}}},
+     #ejabberd_commands{name = get_room_affiliations, tags = [muc_room],
+			desc = "Get the list of affiliations of a MUC room",
+			module = ?MODULE, function = get_room_affiliations_v3,
+			version = 3,
+			note = "updated in 24.12",
+		        args_desc = ["Room name", "MUC service"],
+		        args_example = ["room1", "conference.example.com"],
+		        result_desc = "The list of affiliations with jid, affiliation and reason",
+			result_example = [{"user1@example.com", member, "member"}],
+			args = [{room, binary}, {service, binary}],
+			result = {affiliations, {list,
+						 {affiliation, {tuple,
+								[{jid, string},
+								 {affiliation, atom},
+								 {reason, string}
+								]}}
+						}}},
+
+
 	 #ejabberd_commands{name = get_room_affiliation, tags = [muc_room],
 			desc = "Get affiliation of a user in MUC room",
 			module = ?MODULE, function = get_room_affiliation,
@@ -486,7 +602,8 @@ get_commands_spec() ->
 			args_example = ["room1", "conference.example.com", "user1@example.com"],
 			result_desc = "Affiliation of the user",
 			result_example = member,
-			args = [{name, binary}, {service, binary}, {jid, binary}],
+			args = [{room, binary}, {service, binary}, {jid, binary}],
+		        args_rename = [{name, room}],
 			result = {affiliation, atom}},
          #ejabberd_commands{name = get_room_history, tags = [muc_room],
 			desc = "Get history of messages stored inside MUC room state",
@@ -494,7 +611,8 @@ get_commands_spec() ->
 			module = ?MODULE, function = get_room_history,
 			args_desc = ["Room name", "MUC service"],
 			args_example = ["room1", "conference.example.com"],
-			args = [{name, binary}, {service, binary}],
+			args = [{room, binary}, {service, binary}],
+		        args_rename = [{name, room}],
 			result = {history, {list,
 					    {entry, {tuple,
 						     [{timestamp, string},
@@ -546,6 +664,9 @@ build_summary_room(Name, Host, Pid) ->
      Participants
     }.
 
+muc_register_nick(Nick, User, Host, Service) ->
+    muc_register_nick(Nick, makeencode(User, Host), Service).
+
 muc_register_nick(Nick, FromBinary, Service) ->
     try {get_room_serverhost(Service), jid:decode(FromBinary)} of
 	{ServerHost, From} ->
@@ -568,6 +689,9 @@ muc_register_nick(Nick, FromBinary, Service) ->
 	    throw({error, "Internal error"})
     end.
 
+muc_unregister_nick(User, Host, Service) ->
+    muc_unregister_nick(makeencode(User, Host), Service).
+
 muc_unregister_nick(FromBinary, Service) ->
     muc_register_nick(<<"">>, FromBinary, Service).
 
@@ -727,12 +851,13 @@ webadmin_muc_host(_Host,
         make_breadcrumb({room_section, Level, Service, <<"Affiliations">>, Name, R, RPath}),
     Set = [make_command(set_room_affiliation,
                         R,
-                        [{<<"name">>, Name}, {<<"service">>, Service}],
+                        [{<<"room">>, Name}, {<<"service">>, Service}],
                         [])],
     Get = [make_command(get_room_affiliations,
                         R,
-                        [{<<"name">>, Name}, {<<"service">>, Service}],
-                        [{table_options, {20, RPath}}])],
+                        [{<<"room">>, Name}, {<<"service">>, Service}],
+                        [{table_options, {20, RPath}},
+                         {result_links, [{jid, user, 3 + Level, <<"">>}]}])],
     Title ++ Breadcrumb ++ Get ++ Set;
 webadmin_muc_host(_Host,
                   Service,
@@ -746,7 +871,7 @@ webadmin_muc_host(_Host,
         make_breadcrumb({room_section, Level, Service, <<"History">>, Name, R, RPath}),
     Get = [make_command(get_room_history,
                         R,
-                        [{<<"name">>, Name}, {<<"service">>, Service}],
+                        [{<<"room">>, Name}, {<<"service">>, Service}],
                         [{table_options, {10, RPath}},
                          {result_links, [{message, paragraph, 1, <<"">>}]}])],
     Title ++ Breadcrumb ++ Get;
@@ -762,7 +887,7 @@ webadmin_muc_host(_Host,
         make_breadcrumb({room_section, Level, Service, <<"Invite">>, Name, R, RPath}),
     Set = [make_command(send_direct_invitation,
                         R,
-                        [{<<"name">>, Name}, {<<"service">>, Service}],
+                        [{<<"room">>, Name}, {<<"service">>, Service}],
                         [])],
     Title ++ Breadcrumb ++ Set;
 webadmin_muc_host(_Host,
@@ -777,7 +902,7 @@ webadmin_muc_host(_Host,
         make_breadcrumb({room_section, Level, Service, <<"Occupants">>, Name, R, RPath}),
     Get = [make_command(get_room_occupants,
                         R,
-                        [{<<"name">>, Name}, {<<"service">>, Service}],
+                        [{<<"room">>, Name}, {<<"service">>, Service}],
                         [{table_options, {20, RPath}},
                          {result_links, [{jid, user, 3 + Level, <<"">>}]}])],
     Title ++ Breadcrumb ++ Get;
@@ -793,11 +918,11 @@ webadmin_muc_host(_Host,
         make_breadcrumb({room_section, Level, Service, <<"Options">>, Name, R, RPath}),
     Set = [make_command(change_room_option,
                         R,
-                        [{<<"name">>, Name}, {<<"service">>, Service}],
+                        [{<<"room">>, Name}, {<<"service">>, Service}],
                         [])],
     Get = [make_command(get_room_options,
                         R,
-                        [{<<"name">>, Name}, {<<"service">>, Service}],
+                        [{<<"room">>, Name}, {<<"service">>, Service}],
                         [])],
     Title ++ Breadcrumb ++ Get ++ Set;
 webadmin_muc_host(_Host,
@@ -815,15 +940,15 @@ webadmin_muc_host(_Host,
         make_breadcrumb({room_section, Level, Service, <<"Subscribers">>, Name, R, RPath}),
     Set = [make_command(subscribe_room,
                         R,
-                        [{<<"room">>, jid:encode({Name, Service, <<"">>})}],
+                        [{<<"room">>, Name}, {<<"service">>, Service}],
                         []),
            make_command(unsubscribe_room,
                         R,
-                        [{<<"room">>, jid:encode({Name, Service, <<"">>})}],
+                        [{<<"room">>, Name}, {<<"service">>, Service}],
                         [{style, danger}])],
     Get = [make_command(get_subscribers,
                         R,
-                        [{<<"name">>, Name}, {<<"service">>, Service}],
+                        [{<<"room">>, Name}, {<<"service">>, Service}],
                         [{table_options, {20, RPath}},
                          {result_links, [{jid, user, 3 + Level, <<"">>}]}])],
     Title ++ Breadcrumb ++ Get ++ Set;
@@ -839,7 +964,7 @@ webadmin_muc_host(_Host,
         make_breadcrumb({room_section, Level, Service, <<"Destroy">>, Name, R, RPath}),
     Set = [make_command(destroy_room,
                         R,
-                        [{<<"name">>, Name}, {<<"service">>, Service}],
+                        [{<<"room">>, Name}, {<<"service">>, Service}],
                         [{style, danger}])],
     Title ++ Breadcrumb ++ Set;
 webadmin_muc_host(_Host,
@@ -875,7 +1000,7 @@ webadmin_muc_host(_Host, Service, [<<"rooms">> | RPath], R, _Lang, Level, PageTi
                                     {result_links, [{sentence, room, 3 + Level, <<"">>}]}]),
                       make_command(get_room_occupants_number,
                                    R,
-                                   [{<<"name">>, Name}, {<<"service">>, Service}],
+                                   [{<<"room">>, Name}, {<<"service">>, Service}],
                                    [{only, raw_and_value}])}
                   end,
                   make_command_raw_value(muc_online_rooms, R, [{<<"service">>, Service}])),
@@ -1148,7 +1273,7 @@ create_room(Name1, Host1, ServerHost) ->
 
 create_room_with_opts(Name1, Host1, ServerHost1, CustomRoomOpts) ->
     ServerHost = validate_host(ServerHost1, <<"serverhost">>),
-    case get_room_pid_validate(Name1, Host1, <<"name">>, <<"host">>) of
+    case get_room_pid_validate(Name1, Host1, <<"service">>) of
 	{room_not_found, Name, Host} ->
 	    %% Get the default room options from the muc configuration
 	    DefRoomOpts = mod_muc_opt:default_room_options(ServerHost),
@@ -1178,7 +1303,7 @@ muc_create_room(ServerHost, {Name, Host, _}, DefRoomOpts) ->
 %% If the room has participants, they are not notified that the room was destroyed;
 %% they will notice when they try to chat and receive an error that the room doesn't exist.
 destroy_room(Name1, Service1) ->
-    case get_room_pid_validate(Name1, Service1, <<"name">>, <<"service">>) of
+    case get_room_pid_validate(Name1, Service1, <<"service">>) of
 	{room_not_found, _, _} ->
 	    throw({error, "Room doesn't exists"});
 	{Pid, _, _} ->
@@ -1245,11 +1370,31 @@ create_rooms_file(Filename) ->
     RJID = read_room(F),
     Rooms = read_rooms(F, RJID, []),
     file:close(F),
-    %% Read the default room options defined for the first virtual host
-    DefRoomOpts = mod_muc_opt:default_room_options(ejabberd_config:get_myname()),
-    [muc_create_room(ejabberd_config:get_myname(), A, DefRoomOpts) || A <- Rooms],
+    HostsDetails = get_hosts_details(Rooms),
+    [muc_create_room(HostsDetails, A) || A <- Rooms],
     ok.
 
+muc_create_room(HostsDetails, {_, Host, _} = RoomTuple) ->
+    {_Host, ServerHost, DefRoomOpts} = get_host_details(Host, HostsDetails),
+    muc_create_room(ServerHost, RoomTuple, DefRoomOpts).
+
+get_hosts_details(Rooms) ->
+    Hosts = lists_uniq([Host || {_, Host, _} <- Rooms]),
+    lists:map(fun(H) ->
+                      SH = get_room_serverhost(H),
+                      {H, SH, mod_muc_opt:default_room_options(SH)}
+              end, Hosts).
+
+-ifdef(OTP_BELOW_25).
+lists_uniq(List) ->
+    lists:usort(List).
+-else.
+lists_uniq(List) ->
+    lists:uniq(List).
+-endif.
+
+get_host_details(Host, ServerHostsDetails) ->
+    lists:keyfind(Host, 1, ServerHostsDetails).
 
 %%---------------------------------
 %% List/Delete Unused/Empty Rooms
@@ -1454,7 +1599,7 @@ act_on_room(_Method, list, _) ->
 %%----------------------------
 
 get_room_occupants(Room, Host) ->
-    case get_room_pid_validate(Room, Host, <<"name">>, <<"service">>) of
+    case get_room_pid_validate(Room, Host, <<"service">>) of
 	{Pid, _, _} when is_pid(Pid) -> get_room_occupants(Pid);
 	_ -> throw({error, room_not_found})
     end.
@@ -1470,7 +1615,7 @@ get_room_occupants(Pid) ->
       maps:to_list(S#state.users)).
 
 get_room_occupants_number(Room, Host) ->
-    case get_room_pid_validate(Room, Host, <<"name">>, <<"service">>) of
+    case get_room_pid_validate(Room, Host, <<"service">>) of
 	{Pid, _, _} when is_pid(Pid)->
 	    {ok, #{occupants_number := N}} = mod_muc_room:get_info(Pid),
 	    N;
@@ -1549,7 +1694,7 @@ send_direct_invitation(FromJid, UserJid, Msg) ->
 %% For example:
 %% `change_room_option(<<"testroom">>, <<"conference.localhost">>, <<"title">>, <<"Test Room">>)'
 change_room_option(Name, Service, OptionString, ValueString) ->
-    case get_room_pid_validate(Name, Service, <<"name">>, <<"service">>) of
+    case get_room_pid_validate(Name, Service, <<"service">>) of
 	{room_not_found, _, _} ->
 	    throw({error, "Room not found"});
 	{Pid, _, _} ->
@@ -1646,10 +1791,10 @@ parse_nodes([<<"subscribers">> | Rest], Acc) ->
 parse_nodes(_, _) ->
     throw({error, "Invalid 'subscribers' - unknown node name used"}).
 
--spec get_room_pid_validate(binary(), binary(), binary(), binary()) ->
+-spec get_room_pid_validate(binary(), binary(), binary()) ->
     {pid() | room_not_found, binary(), binary()}.
-get_room_pid_validate(Name, Service, NameArg, ServiceArg) ->
-    Name2 = validate_room(Name, NameArg),
+get_room_pid_validate(Name, Service, ServiceArg) ->
+    Name2 = validate_room(Name),
     {ServerHost, Service2} = validate_muc2(Service, ServiceArg),
     case mod_muc:unhibernate_room(ServerHost, Service2, Name2) of
 	error ->
@@ -1740,7 +1885,7 @@ change_option(Option, Value, Config) ->
 %%----------------------------
 
 get_room_options(Name, Service) ->
-    case get_room_pid_validate(Name, Service, <<"name">>, <<"service">>) of
+    case get_room_pid_validate(Name, Service, <<"service">>) of
 	{Pid, _, _} when is_pid(Pid) -> get_room_options(Pid);
 	_ -> []
     end.
@@ -1763,10 +1908,10 @@ get_options(Config) ->
 %%----------------------------
 
 %% @spec(Name::binary(), Service::binary()) ->
-%%    [{JID::string(), Domain::string(), Role::string(), Reason::string()}]
+%%    [{Username::string(), Domain::string(), Role::string(), Reason::string()}]
 %% @doc Get the affiliations of  the room Name@Service.
 get_room_affiliations(Name, Service) ->
-    case get_room_pid_validate(Name, Service, <<"name">>, <<"service">>) of
+    case get_room_pid_validate(Name, Service, <<"service">>) of
 	{Pid, _, _} when is_pid(Pid) ->
 	    %% Get the PID of the online room, then request its state
 	    {ok, StateData} = mod_muc_room:get_state(Pid),
@@ -1781,8 +1926,29 @@ get_room_affiliations(Name, Service) ->
 	    throw({error, "The room does not exist."})
     end.
 
+%% @spec(Name::binary(), Service::binary()) ->
+%%    [{JID::string(), Role::string(), Reason::string()}]
+%% @doc Get the affiliations of  the room Name@Service.
+get_room_affiliations_v3(Name, Service) ->
+    case get_room_pid_validate(Name, Service, <<"service">>) of
+	{Pid, _, _} when is_pid(Pid) ->
+	    %% Get the PID of the online room, then request its state
+	    {ok, StateData} = mod_muc_room:get_state(Pid),
+	    Affiliations = maps:to_list(StateData#state.affiliations),
+	    lists:map(
+	      fun({{Uname, Domain, _Res}, {Aff, Reason}}) when is_atom(Aff)->
+		      Jid = makeencode(Uname, Domain),
+		      {Jid, Aff, Reason};
+		 ({{Uname, Domain, _Res}, Aff}) when is_atom(Aff)->
+		      Jid = makeencode(Uname, Domain),
+		      {Jid, Aff, <<>>}
+	      end, Affiliations);
+	_ ->
+	    throw({error, "The room does not exist."})
+    end.
+
 get_room_history(Name, Service) ->
-    case get_room_pid_validate(Name, Service, <<"name">>, <<"service">>) of
+    case get_room_pid_validate(Name, Service, <<"service">>) of
 	{Pid, _, _} when is_pid(Pid) ->
 	    case mod_muc_room:get_state(Pid) of
 		{ok, StateData} ->
@@ -1808,7 +1974,7 @@ get_room_history(Name, Service) ->
 %% @doc Get affiliation of a user in the room Name@Service.
 
 get_room_affiliation(Name, Service, JID) ->
-    case get_room_pid_validate(Name, Service, <<"name">>, <<"service">>) of
+    case get_room_pid_validate(Name, Service, <<"service">>) of
 	{Pid, _, _} when is_pid(Pid) ->
 	    %% Get the PID of the online room, then request its state
 	    {ok, StateData} = mod_muc_room:get_state(Pid),
@@ -1822,6 +1988,9 @@ get_room_affiliation(Name, Service, JID) ->
 %% Change Room Affiliation
 %%----------------------------
 
+set_room_affiliation(Name, Service, User, Host, AffiliationString) ->
+    set_room_affiliation(Name, Service, makeencode(User, Host), AffiliationString).
+
 %% @spec(Name, Service, JID, AffiliationString) -> ok | {error, Error}
 %%       Name = binary()
 %%       Service = binary()
@@ -1840,7 +2009,7 @@ set_room_affiliation(Name, Service, JID, AffiliationString) ->
                       _ ->
                           throw({error, "Invalid affiliation"})
                   end,
-    case get_room_pid_validate(Name, Service, <<"name">>, <<"service">>) of
+    case get_room_pid_validate(Name, Service, <<"service">>) of
 	{Pid, _, _} when is_pid(Pid) ->
 	    %% Get the PID for the online room so we can get the state of the room
 	    case mod_muc_room:change_item(Pid, jid:decode(JID), affiliation, Affiliation, <<"">>) of
@@ -1859,6 +2028,10 @@ set_room_affiliation(Name, Service, JID, AffiliationString) ->
 %%% MUC Subscription
 %%%
 
+subscribe_room(Username, Host, Nick, Name, Service, Nodes) ->
+    subscribe_room(makeencode(Username, Host), Nick,
+                   makeencode(Name, Service), Nodes).
+
 subscribe_room(_User, Nick, _Room, _Nodes) when Nick == <<"">> ->
     throw({error, "Nickname must be set"});
 subscribe_room(User, Nick, Room, Nodes) when is_binary(Nodes) ->
@@ -1870,7 +2043,7 @@ subscribe_room(User, Nick, Room, NodeList) ->
 	    try jid:decode(User) of
 		UserJID1 ->
 		    UserJID = jid:replace_resource(UserJID1, <<"modmucadmin">>),
-		    case get_room_pid_validate(Name, Host, <<"name">>, <<"room">>) of
+		    case get_room_pid_validate(Name, Host, <<"service">>) of
 			{Pid, _, _} when is_pid(Pid) ->
 			    case mod_muc_room:subscribe(
 				   Pid, UserJID, Nick, NodeList) of
@@ -1891,6 +2064,10 @@ subscribe_room(User, Nick, Room, NodeList) ->
 	    throw({error, "Malformed room JID"})
     end.
 
+subscribe_room_many_v3(List, Name, Service, Nodes) ->
+    List2 = [{makeencode(User, Host), Nick} || {User, Host, Nick} <- List],
+    subscribe_room_many(List2, makeencode(Name, Service), Nodes).
+
 subscribe_room_many(Users, Room, Nodes) ->
     MaxUsers = mod_muc_admin_opt:subscribe_room_many_max_users(global),
     if
@@ -1903,12 +2080,16 @@ subscribe_room_many(Users, Room, Nodes) ->
               end, Users)
     end.
 
+unsubscribe_room(User, Host, Name, Service) ->
+    unsubscribe_room(makeencode(User, Host),
+                     makeencode(Name, Service)).
+
 unsubscribe_room(User, Room) ->
     try jid:decode(Room) of
 	#jid{luser = Name, lserver = Host} when Name /= <<"">> ->
 	    try jid:decode(User) of
 		UserJID ->
-		    case get_room_pid_validate(Name, Host, <<"name">>, <<"room">>) of
+		    case get_room_pid_validate(Name, Host, <<"service">>) of
 			{Pid, _, _} when is_pid(Pid) ->
 			    case mod_muc_room:unsubscribe(Pid, UserJID) of
 				ok ->
@@ -1929,7 +2110,7 @@ unsubscribe_room(User, Room) ->
     end.
 
 get_subscribers(Name, Host) ->
-    case get_room_pid_validate(Name, Host, <<"name">>, <<"service">>) of
+    case get_room_pid_validate(Name, Host, <<"service">>) of
 	{Pid, _, _} when is_pid(Pid) ->
 	    {ok, JIDList} = mod_muc_room:get_subscribers(Pid),
 	    [jid:encode(jid:remove_resource(J)) || J <- JIDList];
@@ -1941,6 +2122,9 @@ get_subscribers(Name, Host) ->
 %% Utils
 %%----------------------------
 
+makeencode(User, Host) ->
+    jid:encode(jid:make(User, Host)).
+
 -spec validate_host(Name :: binary(), ArgName::binary()) -> binary().
 validate_host(Name, ArgName) ->
     case jid:nameprep(Name) of
@@ -1996,11 +2180,11 @@ validate_muc2(Name, ArgName) ->
 	    end
     end.
 
--spec validate_room(Name :: binary(), ArgName :: binary()) -> binary().
-validate_room(Name, ArgName) ->
+-spec validate_room(Name :: binary()) -> binary().
+validate_room(Name) ->
     case jid:nodeprep(Name) of
 	error ->
-	    throw({error, <<"Invalid value of '",ArgName/binary,"'">>});
+	    throw({error, <<"Invalid value of room name">>});
 	Name2 ->
 	    Name2
     end.
@@ -2075,5 +2259,5 @@ mod_doc() ->
               note => "added in 22.05",
               desc =>
                   ?T("How many users can be subscribed to a room at once using "
-                     "the 'subscribe_room_many' command. "
+                     "the _`subscribe_room_many`_ API. "
                      "The default value is '50'.")}}]}.
