@@ -27,9 +27,9 @@
 
 -author('alexey@process-one.net').
 
--protocol({xep, 49, '1.2'}).
--protocol({xep, 411, '0.2.0', '18.12', "", ""}).
--protocol({xep, 402, '1.1.3', '23.10', "", ""}).
+-protocol({xep, 49, '1.2', '0.1.0', "complete", ""}).
+-protocol({xep, 411, '0.2.0', '18.12', "complete", ""}).
+-protocol({xep, 402, '1.1.3', '23.10', "complete", ""}).
 
 -behaviour(gen_mod).
 
@@ -135,7 +135,7 @@ mod_doc() ->
               "[XEP-0048: Bookmarks])."), "",
            ?T("It also implements the bookmark conversion described in "
               "https://xmpp.org/extensions/xep-0402.html[XEP-0402: PEP Native Bookmarks]"
-              ", see the command _`bookmarks_to_pep`_ API.")],
+              ", see _`bookmarks_to_pep`_ API.")],
       opts =>
           [{db_type,
             #{value => "mnesia | sql",
