@@ -383,7 +383,7 @@ mod_doc() ->
            ?T("NOTE: It is not enough to just load this module. "
               "You should also configure listeners and DNS records "
               "properly. For details see the section about the "
-              "http://../listen/#ejabberd-sip[ejabberd_sip] listen module "
+              "_`listen.md#ejabberd_sip|ejabberd_sip`_ listen module "
               "in the ejabberd Documentation.")],
       opts =>
           [{always_record_route,
@@ -437,7 +437,6 @@ mod_doc() ->
                      "cannot omit \"port\" or \"scheme\").")}}],
       example =>
           ["modules:",
-           "  ...",
            "  mod_sip:",
            "    always_record_route: false",
            "    record_route: \"sip:example.com;lr\"",
@@ -449,7 +448,6 @@ mod_doc() ->
            "    via:",
            "      - tls://sip-tls.example.com:5061",
            "      - tcp://sip-tcp.example.com:5060",
-           "      - udp://sip-udp.example.com:5060",
-           "  ..."]}.
+           "      - udp://sip-udp.example.com:5060"]}.
 
 -endif.
