@@ -23,7 +23,7 @@
 -module(mod_stream_mgmt).
 -behaviour(gen_mod).
 -author('holger@zedat.fu-berlin.de').
--protocol({xep, 198, '1.5.2', '14.05', "", ""}).
+-protocol({xep, 198, '1.5.2', '14.05', "complete", ""}).
 
 %% gen_mod API
 -export([start/2, stop/1, reload/3, depends/2, mod_opt_type/1, mod_options/1]).
